/**
 * Copyright (c) 2002-2013 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.test;

import java.io.IOException;

import org.junit.rules.TemporaryFolder;
import org.neo4j.graphdb.factory.GraphDatabaseBuilder;
import org.neo4j.graphdb.factory.GraphDatabaseFactory;

/**
 * JUnit @Rule for configuring, creating and managing an EmbeddedGraphDatabase instance.
 */
public class EmbeddedDatabaseRule extends DatabaseRule
{
    private final TemporaryFolder temp = new TemporaryFolder();
    
    @Override
    protected GraphDatabaseFactory newFactory()
    {
        return new GraphDatabaseFactory();
    }
    
    @Override
    protected GraphDatabaseBuilder newBuilder( GraphDatabaseFactory factory )
    {
        return factory.newEmbeddedDatabaseBuilder( temp.getRoot().getAbsolutePath() );
    }

    @Override
    protected void createResources() throws IOException
    {
        temp.create();
    }
    
    @Override
    protected void deleteResources()
    {
        temp.delete();
    }
}
